# Troop-auth

![PUBLISH](https://github.com/binaryai/sdk/workflows/PUBLISH/badge.svg)

## Installation

```shell
pip install django-troop-auth
```

## Documentation

Please see the <a>Documentation</a> for more details.